@@ -28,11 +28,10 @@ class ContainerWorker(ABC):
         self.changed = False
         # Use this to store arguments to pass to exit_json().
         self.result = {}
-        self._cgroupns_mode_supported = True
 
         self.systemd = SystemdWorker(self.params)
 
-        # NOTE(mgoddard): The names used by Docker are inconsisent between
+        # NOTE(mgoddard): The names used by Docker are inconsistent between
         # configuration of a container's resources and the resources in
         # container_info['HostConfig']. This provides a mapping between the
         # two.
@@ -141,8 +140,6 @@ class ContainerWorker(ABC):
         pass
 
     def compare_cgroupns_mode(self, container_info):
-        if not self._cgroupns_mode_supported:
-            return False
         new_cgroupns_mode = self.params.get('cgroupns_mode')
         if new_cgroupns_mode is None:
             # means we don't care what it is
